Description Super class Methods
Output both the point estimate and the bootstrap confidence interval
TMLEbootstrap::generalBootstrap -> ateBootstrap
new()ateBootstrap$new( data, family_y, lambda1 = NULL, lambda2 = NULL, M1 = NULL, M2 = NULL, targeting = TRUE )
bootstrap_once()ateBootstrap$bootstrap_once(self, data)
run_bootstrap()ateBootstrap$run_bootstrap(n_bootstrap = 200, alpha = 0.05, kind = NULL)
clone()The objects of this class are cloneable with this method.
ateBootstrap$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.