Description Super class Methods
Output both the point estimate and the bootstrap confidence interval
TMLEbootstrap::generalBootstrap -> blipVarianceBootstrap
new()blipVarianceBootstrap$new(data, verbose = NULL, targeting = TRUE, ...)
bootstrap_once()blipVarianceBootstrap$bootstrap_once(self, data, population_tmle)
run_bootstrap()blipVarianceBootstrap$run_bootstrap( n_bootstrap = 200, alpha = 0.05, kind = NULL )
clone()The objects of this class are cloneable with this method.
blipVarianceBootstrap$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.